@@ -28,6 +28,8 @@ fn show_all_as_many_as_the_size_of_terminal_without_query() {
             b"\x1b[1;1H\x1b[J",
             b"Search: \x1b7\x1b[1E",
             b"> .browserslistrc\x1b[1E",
+            b"  .config/bar.toml\x1b[1E",
+            b"  .config/ok.toml\x1b[1E",
             b"  .editorconfig\x1b[1E",
             b"  .env\x1b[1E",
             b"  .env.local\x1b[1E",
@@ -37,15 +39,13 @@ fn show_all_as_many_as_the_size_of_terminal_without_query() {
             b"  Dockerfile\x1b[1E",
             b"  LICENSE\x1b[1E",
             b"  README.md\x1b[1E",
-            b"  package-lock.json\x1b[1E",
-            b"  package.json\x1b[1E",
-            b"  tsconfig.json\x1b[1E",
-            b"  \xe2\x98\x95.txt\x1b[1E",
-            b"  .config/bar.toml\x1b[1E",
-            b"  .config/ok.toml\x1b[1E",
+            b"  lib/a/b/c/index.js\x1b[1E",
+            b"  lib/a/b/c/\xe2\x98\x95.js\x1b[1E",
+            b"  lib/a/b/index.js\x1b[1E",
+            b"  lib/a/index.js\x1b[1E",
             b"  lib/bar.js\x1b[1E",
-            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                 \x1b[0m\x1b[1E",
-            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute",
+            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                                   \x1b[0m\x1b[1E",
+            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute\x1b[2C\x1b[1m<C-d>/<C-y>:\x1b[0m\x1b[1CCopy (relative/absolute)",
             b"\x1b8\x1b[?1049l"
         )
     );
@@ -73,8 +73,8 @@ fn show_filtered_paths_with_query() {
             b"\x1b[1;1H\x1b[J",
             b"Search: browser\x1b7\x1b[1E",
             b"> .\x1b[1mbrowse\x1b[0mrslist\x1b[1mr\x1b[0mc\x1b[1E",
-            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                 \x1b[0m\x1b[1E",
-            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute",
+            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                                   \x1b[0m\x1b[1E",
+            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute\x1b[2C\x1b[1m<C-d>/<C-y>:\x1b[0m\x1b[1CCopy (relative/absolute)",
             b"\x1b8\x1b[?1049l"
         )
     );
@@ -109,6 +109,8 @@ fn show_filtered_paths_with_query_interactively() {
             b"\x1b[1;1H\x1b[J",
             b"Search: \x1b7\x1b[1E",
             b"> .browserslistrc\x1b[1E",
+            b"  .config/bar.toml\x1b[1E",
+            b"  .config/ok.toml\x1b[1E",
             b"  .editorconfig\x1b[1E",
             b"  .env\x1b[1E",
             b"  .env.local\x1b[1E",
@@ -118,19 +120,19 @@ fn show_filtered_paths_with_query_interactively() {
             b"  Dockerfile\x1b[1E",
             b"  LICENSE\x1b[1E",
             b"  README.md\x1b[1E",
-            b"  package-lock.json\x1b[1E",
-            b"  package.json\x1b[1E",
-            b"  tsconfig.json\x1b[1E",
-            b"  \xe2\x98\x95.txt\x1b[1E",
-            b"  .config/bar.toml\x1b[1E",
-            b"  .config/ok.toml\x1b[1E",
+            b"  lib/a/b/c/index.js\x1b[1E",
+            b"  lib/a/b/c/\xe2\x98\x95.js\x1b[1E",
+            b"  lib/a/b/index.js\x1b[1E",
+            b"  lib/a/index.js\x1b[1E",
             b"  lib/bar.js\x1b[1E",
-            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                 \x1b[0m\x1b[1E",
-            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute",
+            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                                   \x1b[0m\x1b[1E",
+            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute\x1b[2C\x1b[1m<C-d>/<C-y>:\x1b[0m\x1b[1CCopy (relative/absolute)",
             b"\x1b8",
             b"\x1b[1;1H\x1b[J",
             b"Search: b\x1b7\x1b[1E",
             b"> .browserslistrc\x1b[1E",
+            b"  .config/bar.toml\x1b[1E",
+            b"  .config/ok.toml\x1b[1E",
             b"  .editorconfig\x1b[1E",
             b"  .env\x1b[1E",
             b"  .env.local\x1b[1E",
@@ -140,19 +142,19 @@ fn show_filtered_paths_with_query_interactively() {
             b"  Dockerfile\x1b[1E",
             b"  LICENSE\x1b[1E",
             b"  README.md\x1b[1E",
-            b"  package-lock.json\x1b[1E",
-            b"  package.json\x1b[1E",
-            b"  tsconfig.json\x1b[1E",
-            b"  \xe2\x98\x95.txt\x1b[1E",
-            b"  .config/bar.toml\x1b[1E",
-            b"  .config/ok.toml\x1b[1E",
+            b"  lib/a/b/c/index.js\x1b[1E",
+            b"  lib/a/b/c/\xe2\x98\x95.js\x1b[1E",
+            b"  lib/a/b/index.js\x1b[1E",
+            b"  lib/a/index.js\x1b[1E",
             b"  lib/bar.js\x1b[1E",
-            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                 \x1b[0m\x1b[1E",
-            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute",
+            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                                   \x1b[0m\x1b[1E",
+            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute\x1b[2C\x1b[1m<C-d>/<C-y>:\x1b[0m\x1b[1CCopy (relative/absolute)",
             b"\x1b8",
             b"\x1b[1;1H\x1b[J",
             b"Search: br\x1b7\x1b[1E",
             b"> .browserslistrc\x1b[1E",
+            b"  .config/bar.toml\x1b[1E",
+            b"  .config/ok.toml\x1b[1E",
             b"  .editorconfig\x1b[1E",
             b"  .env\x1b[1E",
             b"  .env.local\x1b[1E",
@@ -162,19 +164,19 @@ fn show_filtered_paths_with_query_interactively() {
             b"  Dockerfile\x1b[1E",
             b"  LICENSE\x1b[1E",
             b"  README.md\x1b[1E",
-            b"  package-lock.json\x1b[1E",
-            b"  package.json\x1b[1E",
-            b"  tsconfig.json\x1b[1E",
-            b"  \xe2\x98\x95.txt\x1b[1E",
-            b"  .config/bar.toml\x1b[1E",
-            b"  .config/ok.toml\x1b[1E",
+            b"  lib/a/b/c/index.js\x1b[1E",
+            b"  lib/a/b/c/\xe2\x98\x95.js\x1b[1E",
+            b"  lib/a/b/index.js\x1b[1E",
+            b"  lib/a/index.js\x1b[1E",
             b"  lib/bar.js\x1b[1E",
-            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                 \x1b[0m\x1b[1E",
-            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute",
+            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                                   \x1b[0m\x1b[1E",
+            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute\x1b[2C\x1b[1m<C-d>/<C-y>:\x1b[0m\x1b[1CCopy (relative/absolute)",
             b"\x1b8",
             b"\x1b[1;1H\x1b[J",
             b"Search: bro\x1b7\x1b[1E",
             b"> .browserslistrc\x1b[1E",
+            b"  .config/bar.toml\x1b[1E",
+            b"  .config/ok.toml\x1b[1E",
             b"  .editorconfig\x1b[1E",
             b"  .env\x1b[1E",
             b"  .env.local\x1b[1E",
@@ -184,19 +186,19 @@ fn show_filtered_paths_with_query_interactively() {
             b"  Dockerfile\x1b[1E",
             b"  LICENSE\x1b[1E",
             b"  README.md\x1b[1E",
-            b"  package-lock.json\x1b[1E",
-            b"  package.json\x1b[1E",
-            b"  tsconfig.json\x1b[1E",
-            b"  \xe2\x98\x95.txt\x1b[1E",
-            b"  .config/bar.toml\x1b[1E",
-            b"  .config/ok.toml\x1b[1E",
+            b"  lib/a/b/c/index.js\x1b[1E",
+            b"  lib/a/b/c/\xe2\x98\x95.js\x1b[1E",
+            b"  lib/a/b/index.js\x1b[1E",
+            b"  lib/a/index.js\x1b[1E",
             b"  lib/bar.js\x1b[1E",
-            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                 \x1b[0m\x1b[1E",
-            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute",
+            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                                   \x1b[0m\x1b[1E",
+            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute\x1b[2C\x1b[1m<C-d>/<C-y>:\x1b[0m\x1b[1CCopy (relative/absolute)",
             b"\x1b8",
             b"\x1b[1;1H\x1b[J",
             b"Search: brow\x1b7\x1b[1E",
             b"> .browserslistrc\x1b[1E",
+            b"  .config/bar.toml\x1b[1E",
+            b"  .config/ok.toml\x1b[1E",
             b"  .editorconfig\x1b[1E",
             b"  .env\x1b[1E",
             b"  .env.local\x1b[1E",
@@ -206,19 +208,19 @@ fn show_filtered_paths_with_query_interactively() {
             b"  Dockerfile\x1b[1E",
             b"  LICENSE\x1b[1E",
             b"  README.md\x1b[1E",
-            b"  package-lock.json\x1b[1E",
-            b"  package.json\x1b[1E",
-            b"  tsconfig.json\x1b[1E",
-            b"  \xe2\x98\x95.txt\x1b[1E",
-            b"  .config/bar.toml\x1b[1E",
-            b"  .config/ok.toml\x1b[1E",
+            b"  lib/a/b/c/index.js\x1b[1E",
+            b"  lib/a/b/c/\xe2\x98\x95.js\x1b[1E",
+            b"  lib/a/b/index.js\x1b[1E",
+            b"  lib/a/index.js\x1b[1E",
             b"  lib/bar.js\x1b[1E",
-            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                 \x1b[0m\x1b[1E",
-            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute",
+            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                                   \x1b[0m\x1b[1E",
+            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute\x1b[2C\x1b[1m<C-d>/<C-y>:\x1b[0m\x1b[1CCopy (relative/absolute)",
             b"\x1b8",
             b"\x1b[1;1H\x1b[J",
             b"Search: brows\x1b7\x1b[1E",
             b"> .browserslistrc\x1b[1E",
+            b"  .config/bar.toml\x1b[1E",
+            b"  .config/ok.toml\x1b[1E",
             b"  .editorconfig\x1b[1E",
             b"  .env\x1b[1E",
             b"  .env.local\x1b[1E",
@@ -228,18 +230,19 @@ fn show_filtered_paths_with_query_interactively() {
             b"  Dockerfile\x1b[1E",
             b"  LICENSE\x1b[1E",
             b"  README.md\x1b[1E",
-            b"  package-lock.json\x1b[1E",
-            b"  package.json\x1b[1E",
-            b"  tsconfig.json\x1b[1E",
-            b"  \xe2\x98\x95.txt\x1b[1E",
-            b"  .config/bar.toml\x1b[1E",
-            b"  .config/ok.toml\x1b[1E",
-            b"  lib/bar.js\x1b[1E\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                 \x1b[0m\x1b[1E",
-            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute",
+            b"  lib/a/b/c/index.js\x1b[1E",
+            b"  lib/a/b/c/\xe2\x98\x95.js\x1b[1E",
+            b"  lib/a/b/index.js\x1b[1E",
+            b"  lib/a/index.js\x1b[1E",
+            b"  lib/bar.js\x1b[1E",
+            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                                   \x1b[0m\x1b[1E",
+            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute\x1b[2C\x1b[1m<C-d>/<C-y>:\x1b[0m\x1b[1CCopy (relative/absolute)",
             b"\x1b8",
             b"\x1b[1;1H\x1b[J",
             b"Search: browse\x1b7\x1b[1E",
             b"> .browserslistrc\x1b[1E",
+            b"  .config/bar.toml\x1b[1E",
+            b"  .config/ok.toml\x1b[1E",
             b"  .editorconfig\x1b[1E",
             b"  .env\x1b[1E",
             b"  .env.local\x1b[1E",
@@ -249,19 +252,19 @@ fn show_filtered_paths_with_query_interactively() {
             b"  Dockerfile\x1b[1E",
             b"  LICENSE\x1b[1E",
             b"  README.md\x1b[1E",
-            b"  package-lock.json\x1b[1E",
-            b"  package.json\x1b[1E",
-            b"  tsconfig.json\x1b[1E",
-            b"  \xe2\x98\x95.txt\x1b[1E",
-            b"  .config/bar.toml\x1b[1E",
-            b"  .config/ok.toml\x1b[1E",
+            b"  lib/a/b/c/index.js\x1b[1E",
+            b"  lib/a/b/c/\xe2\x98\x95.js\x1b[1E",
+            b"  lib/a/b/index.js\x1b[1E",
+            b"  lib/a/index.js\x1b[1E",
             b"  lib/bar.js\x1b[1E",
-            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                 \x1b[0m\x1b[1E",
-            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute",
+            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                                   \x1b[0m\x1b[1E",
+            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute\x1b[2C\x1b[1m<C-d>/<C-y>:\x1b[0m\x1b[1CCopy (relative/absolute)",
             b"\x1b8",
             b"\x1b[1;1H\x1b[J",
             b"Search: browser\x1b7\x1b[1E",
             b"> .browserslistrc\x1b[1E",
+            b"  .config/bar.toml\x1b[1E",
+            b"  .config/ok.toml\x1b[1E",
             b"  .editorconfig\x1b[1E",
             b"  .env\x1b[1E",
             b"  .env.local\x1b[1E",
@@ -271,21 +274,19 @@ fn show_filtered_paths_with_query_interactively() {
             b"  Dockerfile\x1b[1E",
             b"  LICENSE\x1b[1E",
             b"  README.md\x1b[1E",
-            b"  package-lock.json\x1b[1E",
-            b"  package.json\x1b[1E",
-            b"  tsconfig.json\x1b[1E",
-            b"  \xe2\x98\x95.txt\x1b[1E",
-            b"  .config/bar.toml\x1b[1E",
-            b"  .config/ok.toml\x1b[1E",
+            b"  lib/a/b/c/index.js\x1b[1E",
+            b"  lib/a/b/c/\xe2\x98\x95.js\x1b[1E",
+            b"  lib/a/b/index.js\x1b[1E",
+            b"  lib/a/index.js\x1b[1E",
             b"  lib/bar.js\x1b[1E",
-            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                 \x1b[0m\x1b[1E",
-            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute",
+            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                                   \x1b[0m\x1b[1E",
+            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute\x1b[2C\x1b[1m<C-d>/<C-y>:\x1b[0m\x1b[1CCopy (relative/absolute)",
             b"\x1b8",
             b"\x1b[1;1H\x1b[J",
             b"Search: browser\x1b7\x1b[1E",
             b"> .\x1b[1mbrowse\x1b[0mrslist\x1b[1mr\x1b[0mc\x1b[1E",
-            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                 \x1b[0m\x1b[1E",
-            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute",
+            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                                   \x1b[0m\x1b[1E",
+            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute\x1b[2C\x1b[1m<C-d>/<C-y>:\x1b[0m\x1b[1CCopy (relative/absolute)",
             b"\x1b8",
             b"\x1b[?1049l"
         )
@@ -318,6 +319,8 @@ fn show_filtered_paths_with_query_interactively_including_backspace() {
             b"\x1b[1;1H\x1b[J",
             b"Search: \x1b7\x1b[1E",
             b"> .browserslistrc\x1b[1E",
+            b"  .config/bar.toml\x1b[1E",
+            b"  .config/ok.toml\x1b[1E",
             b"  .editorconfig\x1b[1E",
             b"  .env\x1b[1E",
             b"  .env.local\x1b[1E",
@@ -327,19 +330,19 @@ fn show_filtered_paths_with_query_interactively_including_backspace() {
             b"  Dockerfile\x1b[1E",
             b"  LICENSE\x1b[1E",
             b"  README.md\x1b[1E",
-            b"  package-lock.json\x1b[1E",
-            b"  package.json\x1b[1E",
-            b"  tsconfig.json\x1b[1E",
-            b"  \xe2\x98\x95.txt\x1b[1E",
-            b"  .config/bar.toml\x1b[1E",
-            b"  .config/ok.toml\x1b[1E",
+            b"  lib/a/b/c/index.js\x1b[1E",
+            b"  lib/a/b/c/\xe2\x98\x95.js\x1b[1E",
+            b"  lib/a/b/index.js\x1b[1E",
+            b"  lib/a/index.js\x1b[1E",
             b"  lib/bar.js\x1b[1E",
-            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                 \x1b[0m\x1b[1E",
-            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute",
+            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                                   \x1b[0m\x1b[1E",
+            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute\x1b[2C\x1b[1m<C-d>/<C-y>:\x1b[0m\x1b[1CCopy (relative/absolute)",
             b"\x1b8",
             b"\x1b[1;1H\x1b[J",
             b"Search: B\x1b7\x1b[1E",
             b"> .browserslistrc\x1b[1E",
+            b"  .config/bar.toml\x1b[1E",
+            b"  .config/ok.toml\x1b[1E",
             b"  .editorconfig\x1b[1E",
             b"  .env\x1b[1E",
             b"  .env.local\x1b[1E",
@@ -349,19 +352,19 @@ fn show_filtered_paths_with_query_interactively_including_backspace() {
             b"  Dockerfile\x1b[1E",
             b"  LICENSE\x1b[1E",
             b"  README.md\x1b[1E",
-            b"  package-lock.json\x1b[1E",
-            b"  package.json\x1b[1E",
-            b"  tsconfig.json\x1b[1E",
-            b"  \xe2\x98\x95.txt\x1b[1E",
-            b"  .config/bar.toml\x1b[1E",
-            b"  .config/ok.toml\x1b[1E",
+            b"  lib/a/b/c/index.js\x1b[1E",
+            b"  lib/a/b/c/\xe2\x98\x95.js\x1b[1E",
+            b"  lib/a/b/index.js\x1b[1E",
+            b"  lib/a/index.js\x1b[1E",
             b"  lib/bar.js\x1b[1E",
-            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                 \x1b[0m\x1b[1E",
-            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute",
+            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                                   \x1b[0m\x1b[1E",
+            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute\x1b[2C\x1b[1m<C-d>/<C-y>:\x1b[0m\x1b[1CCopy (relative/absolute)",
             b"\x1b8",
             b"\x1b[1;1H\x1b[J",
             b"Search: Br\x1b7\x1b[1E",
             b"> .browserslistrc\x1b[1E",
+            b"  .config/bar.toml\x1b[1E",
+            b"  .config/ok.toml\x1b[1E",
             b"  .editorconfig\x1b[1E",
             b"  .env\x1b[1E",
             b"  .env.local\x1b[1E",
@@ -371,53 +374,51 @@ fn show_filtered_paths_with_query_interactively_including_backspace() {
             b"  Dockerfile\x1b[1E",
             b"  LICENSE\x1b[1E",
             b"  README.md\x1b[1E",
-            b"  package-lock.json\x1b[1E",
-            b"  package.json\x1b[1E",
-            b"  tsconfig.json\x1b[1E",
-            b"  \xe2\x98\x95.txt\x1b[1E",
-            b"  .config/bar.toml\x1b[1E",
-            b"  .config/ok.toml\x1b[1E",
+            b"  lib/a/b/c/index.js\x1b[1E",
+            b"  lib/a/b/c/\xe2\x98\x95.js\x1b[1E",
+            b"  lib/a/b/index.js\x1b[1E",
+            b"  lib/a/index.js\x1b[1E",
             b"  lib/bar.js\x1b[1E",
-            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                 \x1b[0m\x1b[1E",
-            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute",
+            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                                   \x1b[0m\x1b[1E",
+            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute\x1b[2C\x1b[1m<C-d>/<C-y>:\x1b[0m\x1b[1CCopy (relative/absolute)",
             b"\x1b8",
             b"\x1b[1;1H\x1b[J",
             b"Search: Br\x1b7\x1b[1E",
             b"> .config/\x1b[1mb\x1b[0ma\x1b[1mr\x1b[0m.toml\x1b[1E",
             b"  lib/\x1b[1mb\x1b[0ma\x1b[1mr\x1b[0m.js\x1b[1E",
             b"  .\x1b[1mb\x1b[0mrowserslist\x1b[1mr\x1b[0mc\x1b[1E",
-            b"\x1b[19d\x1b[1m\x1b[7m.config/bar.toml                                                                \x1b[0m\x1b[1E",
-            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute",
+            b"\x1b[19d\x1b[1m\x1b[7m.config/bar.toml                                                                                  \x1b[0m\x1b[1E",
+            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute\x1b[2C\x1b[1m<C-d>/<C-y>:\x1b[0m\x1b[1CCopy (relative/absolute)",
             b"\x1b8",
             b"\x1b[1;1H\x1b[J",
             b"Search: B\x1b7\x1b[1E",
             b"> .config/\x1b[1mb\x1b[0ma\x1b[1mr\x1b[0m.toml\x1b[1E",
             b"  lib/\x1b[1mb\x1b[0ma\x1b[1mr\x1b[0m.js\x1b[1E",
             b"  .\x1b[1mb\x1b[0mrowserslist\x1b[1mr\x1b[0mc\x1b[1E",
-            b"\x1b[19d\x1b[1m\x1b[7m.config/bar.toml                                                                \x1b[0m\x1b[1E",
-            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute",
+            b"\x1b[19d\x1b[1m\x1b[7m.config/bar.toml                                                                                  \x1b[0m\x1b[1E",
+            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute\x1b[2C\x1b[1m<C-d>/<C-y>:\x1b[0m\x1b[1CCopy (relative/absolute)",
             b"\x1b8",
             b"\x1b[1;1H\x1b[J",
             b"Search: B\x1b7\x1b[1E",
             b"> .\x1b[1mb\x1b[0mrowserslistrc\x1b[1E",
             b"  .config/\x1b[1mb\x1b[0mar.toml\x1b[1E",
+            b"  lib/a/\x1b[1mb\x1b[0m/c/index.js\x1b[1E",
+            b"  lib/a/\x1b[1mb\x1b[0m/c/\xe2\x98\x95.js\x1b[1E",
+            b"  lib/a/\x1b[1mb\x1b[0m/index.js\x1b[1E",
+            b"  li\x1b[1mb\x1b[0m/a/index.js\x1b[1E",
             b"  lib/\x1b[1mb\x1b[0mar.js\x1b[1E",
             b"  li\x1b[1mb\x1b[0m/df.js\x1b[1E",
             b"  li\x1b[1mb\x1b[0m/index.js\x1b[1E",
             b"  li\x1b[1mb\x1b[0m/ok.js\x1b[1E",
-            b"  li\x1b[1mb\x1b[0m/a/index.js\x1b[1E",
             b"  li\x1b[1mb\x1b[0m/x/index.js\x1b[1E",
             b"  li\x1b[1mb\x1b[0m/x/util.js\x1b[1E",
-            b"  lib/a/\x1b[1mb\x1b[0m/index.js\x1b[1E",
             b"  li\x1b[1mb\x1b[0m/x/y/index.js\x1b[1E",
             b"  li\x1b[1mb\x1b[0m/x/y/util.js\x1b[1E",
-            b"  src/a/\x1b[1mb\x1b[0m/index.js\x1b[1E",
-            b"  lib/a/\x1b[1mb\x1b[0m/c/index.js\x1b[1E",
-            b"  lib/a/\x1b[1mb\x1b[0m/c/\xe2\x98\x95.js\x1b[1E",
             b"  li\x1b[1mb\x1b[0m/x/y/z/index.js\x1b[1E",
             b"  li\x1b[1mb\x1b[0m/x/y/z/util.js\x1b[1E",
-            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                 \x1b[0m\x1b[1E",
-            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute",
+            b"  src/a/\x1b[1mb\x1b[0m/c/index.js\x1b[1E",
+            b"\x1b[19d\x1b[1m\x1b[7m.browserslistrc                                                                                   \x1b[0m\x1b[1E",
+            b"\x1b[1m<Up>/<Ctrl-p>:\x1b[0m\x1b[1CUp\x1b[2C\x1b[1m<Down>/<Ctrl-n>:\x1b[0m\x1b[1CDown\x1b[2C\x1b[1m<Enter>:\x1b[0m\x1b[1CExecute\x1b[2C\x1b[1m<C-d>/<C-y>:\x1b[0m\x1b[1CCopy (relative/absolute)",
             b"\x1b8",
             b"\x1b[?1049l"
         )
